#' @title Honeybee xyz chromaticity colour matching function data
#'
#' @description A dataset containing wavelengths at a 5 nm interval (300 nm to
#'   700 nm) and the corresponding x, y, and z chromaticity coordinates.
#'   Original data from A chroma_spct object with variables as follows:
#'
#' @details
#' \itemize{
#' \item w.length (nm)
#' \item x
#' \item y
#' \item z }
#'
#' @docType data
#' @keywords datasets
#' @format A data frame with 81 rows and 4 variables
#' @family Visual response data examples
#'
"beesxyzCMF.spct"
